from django.apps import apps

from cms import __version__
from cms.api import create_page, create_title


DJANGO_CMS4 = not (__version__ < "4")
DJANGOCMS_VERSIONING = apps.is_installed("djangocms_verisoning")


class TestFixture:
    """Sets up generic setUp and tearDown methods for tests."""

    def setUp(self):
        self.language = "en"
        self.superuser = self.get_superuser()
        return super().setUp()

    def tearDown(self):
        if DJANGOCMS_VERSIONING:
            from djangocms_versioning.models import Version

            Version.objects.all().delete()
        return super().tearDown()

    if DJANGO_CMS4:  # CMS V4

        def _get_version(self, grouper, version_state, language=None):
            language = language or self.language

            from djangocms_versioning.models import Version

            versions = Version.objects.filter_by_grouper(grouper).filter(
                state=version_state
            )
            for version in versions:
                if (
                    hasattr(version.content, "language")
                    and version.content.language == language
                ):
                    return version
            return None

        def publish(self, grouper, language=None):
            if DJANGOCMS_VERSIONING:
                from djangocms_versioning.constants import DRAFT

                version = self._get_version(grouper, DRAFT, language)
                if version is not None:
                    version.publish(self.superuser)

        def unpublish(self, grouper, language=None):
            if DJANGOCMS_VERSIONING:
                from djangocms_versioning.constants import PUBLISHED

                version = self._get_version(grouper, PUBLISHED, language)
                if version is not None:
                    version.unpublish(self.superuser)

        def create_page(self, title, template, **kwargs):
            kwargs.setdefault("language", self.language)
            kwargs.setdefault("created_by", self.superuser)
            return create_page(title=title, template=template, **kwargs)

        def create_title(self, title, page, **kwargs):
            kwargs.setdefault("language", self.language)
            kwargs.setdefault("created_by", self.superuser)
            kwargs.setdefault("in_navigation", True)
            kwargs.setdefault("limit_visibility_in_menu", None)
            kwargs.setdefault("menu_title", title)
            return create_page(title=title, page=page, **kwargs)

        def get_placeholders(self, page, language=None):
            return page.get_placeholders(language or self.language)

    else:  # CMS V3

        def publish(self, page, language=None):
            page.publish(language)

        def unpublish(self, page, language=None):
            page.unpublish(language)

        def create_page(self, title, template, **kwargs):
            kwargs.setdefault("language", self.language)
            kwargs.setdefault("menu_title", title)
            return create_page(title=title, template=template, **kwargs)

        def create_title(self, title, page, **kwargs):
            kwargs.setdefault("language", self.language)
            kwargs.setdefault("menu_title", title)
            return create_title(title=title, page=page, **kwargs)

        def get_placeholders(self, page, language=None):
            return page.get_placeholders()



from django.db import models

from cms.models import CMSPlugin

from djangocms_text_ckeditor.fields import HTMLField


class SimpleText(models.Model):
    text = HTMLField(blank=True)


class DummyLink(CMSPlugin):
    label = models.TextField()

    class Meta:
        abstract = False

    def __str__(self):
        return 'dummy link object'


class DummySpacer(CMSPlugin):
    class Meta:
        abstract = False

    def __str__(self):
        return 'dummy spacer object'


class Pizza(models.Model):
    description = HTMLField()
    allergens = HTMLField(blank=True)


class Topping(models.Model):
    name = models.CharField(max_length=255)
    description = HTMLField()
    pizza = models.ForeignKey(Pizza, on_delete=models.CASCADE)



from django.conf import settings
from django.templatetags.static import static
from django.utils.translation import gettext_lazy as _


# See http://docs.cksource.com/ckeditor_api/symbols/CKEDITOR.config.html
# for all settings

CKEDITOR_SETTINGS = {
    'language': '{{ language }}',
    'toolbar': 'CMS',
    'skin': 'moono-lisa',
    'baseFloatZIndex': 10000000,
    'toolbarCanCollapse': False,
    **getattr(settings, 'CKEDITOR_SETTINGS', {}),
}

INSTALLED_APPS = getattr(settings, 'INSTALLED_APPS', [])
if 'cms.plugins.picture' in INSTALLED_APPS or 'djangocms_picture' in INSTALLED_APPS:
    save_function_default = 'djangocms_text_ckeditor.picture_save.create_picture_plugin'
else:
    save_function_default = None

TEXT_SAVE_IMAGE_FUNCTION = getattr(settings, 'TEXT_SAVE_IMAGE_FUNCTION', save_function_default)
TEXT_ADDITIONAL_TAGS = getattr(settings, 'TEXT_ADDITIONAL_TAGS', ())
TEXT_ADDITIONAL_ATTRIBUTES = getattr(settings, 'TEXT_ADDITIONAL_ATTRIBUTES', ())
TEXT_ADDITIONAL_PROTOCOLS = getattr(settings, 'TEXT_ADDITIONAL_PROTOCOLS', ())
TEXT_CKEDITOR_CONFIGURATION = getattr(settings, 'TEXT_CKEDITOR_CONFIGURATION', None)
TEXT_HTML_SANITIZE = getattr(settings, 'TEXT_HTML_SANITIZE', True)
# This would make sure correct urls are created for
# when static files are hosted on django and on a CDN. Old code was working fine for Django but not for CDNs.
TEXT_CKEDITOR_BASE_PATH = getattr(
    settings, 'TEXT_CKEDITOR_BASE_PATH', static('djangocms_text_ckeditor/ckeditor/'),
)
TEXT_AUTO_HYPHENATE = getattr(settings, 'TEXT_AUTO_HYPHENATE', True)
TEXT_PLUGIN_NAME = getattr(settings, 'TEXT_PLUGIN_NAME', _('Text'))
TEXT_PLUGIN_MODULE_NAME = getattr(settings, 'TEXT_PLUGIN_MODULE_NAME', _('Generic'))

ALLOW_TOKEN_PARSERS = (
    'djangocms_text_ckeditor.attribute_parsers.DataAttributeParser',
)
TEXT_INLINE_EDITING = getattr(settings, 'TEXT_INLINE_EDITING', False)



import json
from copy import deepcopy
from itertools import groupby

from django import forms
from django.conf import settings
from django.core.serializers.json import DjangoJSONEncoder
from django.template.loader import render_to_string
from django.templatetags.static import static
from django.utils.safestring import mark_safe
from django.utils.translation.trans_real import get_language, gettext

from cms.utils.urlutils import admin_reverse, static_with_version

from . import settings as text_settings
from .utils import cms_placeholder_add_plugin


# this path is changed automatically whenever you run `gulp bundle`
PATH_TO_JS = 'djangocms_text_ckeditor/js/dist/bundle-13948e6025.cms.ckeditor.min.js'


class TextEditorWidget(forms.Textarea):
    def __init__(self, attrs=None, installed_plugins=None, pk=None,
                 placeholder=None, plugin_language=None, plugin_position=None,
                 configuration=None, cancel_url=None, render_plugin_url=None, action_token=None,
                 delete_on_cancel=False, body_css_classes=''):
        """
        Create a widget for editing text + plugins.

        installed_plugins is a list of plugins to display that are text_enabled
        """
        if attrs is None:
            attrs = {}

        self.ckeditor_class = 'CMS_CKEditor'
        if self.ckeditor_class not in attrs.get('class', '').join(' '):
            new_class = attrs.get('class', '') + ' %s' % self.ckeditor_class
            attrs.update({
                'class': new_class.strip(),
            })
        attrs.update({
            'data-ckeditor-basepath': text_settings.TEXT_CKEDITOR_BASE_PATH,
        })
        super().__init__(attrs)
        self.installed_plugins = installed_plugins  # general
        self.pk = pk  # specific
        self.placeholder = placeholder  # specific
        self.plugin_language = plugin_language
        self.plugin_position = plugin_position
        if configuration and getattr(settings, configuration, False):
            conf = deepcopy(text_settings.CKEDITOR_SETTINGS)
            conf.update(getattr(settings, configuration))
            self.configuration = conf  # specific
        else:
            self.configuration = text_settings.CKEDITOR_SETTINGS
        self.cancel_url = cancel_url
        self.render_plugin_url = render_plugin_url
        self.action_token = action_token
        self.delete_on_cancel = delete_on_cancel
        self.body_css_classes = body_css_classes if body_css_classes else self.configuration.get('bodyClass', '')

    @property
    def media(self):
        return forms.Media(
            css={
                'all': ('djangocms_text_ckeditor/css/cms.ckeditor.css',),
            },
            js=(
                static_with_version('cms/js/dist/bundle.admin.base.min.js'),
                static(PATH_TO_JS),
            ),
        )

    def render_textarea(self, name, value, attrs=None, renderer=None):
        return super().render(name, value, attrs, renderer)

    def get_ckeditor_settings(self, language):
        configuration = deepcopy(self.configuration)
        # We are in a plugin -> we use toolbar_CMS or a custom defined toolbar
        if self.placeholder:
            configuration['toolbar'] = configuration.get('toolbar', 'CMS')
        # We are not in a plugin but toolbar is set to CMS (the default) ->
        # we force the use of toolbar_HTMLField
        elif configuration.get('toolbar', False) == 'CMS':
            configuration['toolbar'] = 'HTMLField'
        # Toolbar is not set or set to a custom value -> we use the custom
        # value or fallback to HTMLField
        else:
            configuration['toolbar'] = configuration.get('toolbar', 'HTMLField')

        configuration['bodyClass'] = self.body_css_classes
        config = json.dumps(configuration, cls=DjangoJSONEncoder)

        # Group plugins by module
        if self.installed_plugins:
            plugins = groupby(sorted(self.installed_plugins, key=lambda x: x.get("module")), key=lambda x: x.get("module"))
            plugins = [{'group': group, 'items':
                [{'title': item.get('name'), 'type': item.get('value')} for item in items]} for group, items in plugins]
        else:
            plugins = []

        return {
            'language': language,
            'installed_plugins': self.installed_plugins,
            'static_url': settings.STATIC_URL + 'djangocms_text_ckeditor',
            'plugin_id': self.pk,
            'plugin_language': self.plugin_language,
            'plugin_position': self.plugin_position,
            'placeholder_id': self.placeholder.pk if self.placeholder else None,
            'render_plugin_url': self.render_plugin_url or '',
            'add_plugin_url': admin_reverse(cms_placeholder_add_plugin) if self.placeholder else '',
            'clancel_plugin_url': self.cancel_url or '',
            'delete_on_cancel': self.delete_on_cancel or False,
            'action_token': self.action_token or '',
            'lang': {
                'toolbar': gettext('CMS Plugins'),
                'add': gettext('Add CMS Plugin'),
                'edit': gettext('Edit CMS Plugin'),
                'aria': gettext('CMS Plugins'),
            },
            'plugins': plugins,
            'options': json.loads(config.replace('{{ language }}', language)),
        }

    def render_additions(self, name, value, attrs=None, renderer=None):
        # id attribute is always present when rendering a widget
        ckeditor_selector = attrs['id']
        language = get_language().split('-')[0]

        context = {
            'ckeditor_class': self.ckeditor_class,
            'ckeditor_selector': ckeditor_selector,
            'ckeditor_function': ckeditor_selector.replace('-', '_'),
            'name': name,
            'language': language,
            'STATIC_URL': settings.STATIC_URL,
            'CKEDITOR_BASEPATH': text_settings.TEXT_CKEDITOR_BASE_PATH,
            'installed_plugins': self.installed_plugins,
            'plugin_pk': self.pk,
            'plugin_language': self.plugin_language,
            'plugin_position': self.plugin_position,
            'placeholder': self.placeholder,
            'widget': self,
            'renderer': renderer,
            'ckeditor_settings': self.get_ckeditor_settings(language),
            'ckeditor_settings_id': 'ck-cfg-' + (str(self.pk) if self.pk else ckeditor_selector),
        }
        return mark_safe(render_to_string('cms/plugins/widgets/ckeditor.html', context))

    def render(self, name, value, attrs=None, renderer=None):
        return (
            self.render_textarea(name, value, attrs) + self.render_additions(name, value, attrs, renderer)
        )



from django.apps import AppConfig


class TextCkeditorConfig(AppConfig):
    name = 'djangocms_text_ckeditor'
    verbose_name = 'django CMS Text CKEditor'
    default_auto_field = 'django.db.models.AutoField'



"""
See PEP 440 (https://www.python.org/dev/peps/pep-0440/)

Release logic:
 1. Increase version number (change __version__ below).
 2. Ensure the static bundle is upto date with ``nvm use && gulp bundle``
 3. Assure that all changes have been documented in CHANGELOG.rst.
 4. In setup.py check that
   - versions from all third party packages are pinned in ``REQUIREMENTS``.
   - the list of ``CLASSIFIERS`` is up to date.
 5. git add djangocms_text_ckeditor/__init__.py CHANGELOG.rst setup.py
 6. git commit -m 'Bump to {new version}'
 7. git push
 8. Assure that all tests pass on https://github.com/django-cms/djangocms-text-ckeditor/actions
 9. Create a new release on https://github.com/django-cms/djangocms-text-ckeditor/releases/new
10. Publish the release when ready
11. Github actions will publish the new package to pypi
"""
__version__ = '5.1.3'

default_app_config = 'djangocms_text_ckeditor.apps.TextCkeditorConfig'



#!/usr/bin/env python
import os
import sys
from tempfile import mkdtemp

from cms import __version__


port = 8000

for arg in sys.argv:
    if arg.startswith('--port='):
        port = arg.split('=')[1]


def gettext(s):
    return s


class DisableMigrations(dict):
    def __contains__(self, item):
        return True

    def __getitem__(self, item):
        return None


HELPER_SETTINGS = {
    'SECRET_KEY': 'djangocms-text-ckeditor-test-suite',
    'INSTALLED_APPS': [
        'easy_thumbnails',
        'filer',
        'mptt',
        'djangocms_picture',
        'djangocms_link',
        'djangocms_text_ckeditor',
        'tests.test_app',
    ],
    'CMS_LANGUAGES': {
        1: [
            {
                'code': 'en',
                'name': gettext('English'),
                'public': True,
            },
            {
                'code': 'it',
                'name': gettext('Italiano'),
                'public': True,
            },
            {
                'code': 'fr',
                'name': gettext('French'),
                'public': True,
            },
        ],
        'default': {
            'hide_untranslated': False,
        },
    },
    'LANGUAGES': (
        ('en', gettext('English')),
        ('fr', gettext('French')),
        ('it', gettext('Italiano')),
    ),
    'LANGUAGE_CODE': 'en',
    'ALLOWED_HOSTS': ['localhost'],
    'CMS_PERMISSION': False,
    'CMS_PLACEHOLDER_CONF': {
        'content': {
            'plugins': ['TextPlugin', 'PicturePlugin'],
            'text_only_plugins': ['LinkPlugin'],
            'extra_context': {'width': 640},
            'name': gettext('Content'),
            'language_fallback': True,
            'default_plugins': [
                {
                    'plugin_type': 'TextPlugin',
                    'values': {
                        'body': '<p>Lorem ipsum dolor sit amet...</p>',
                    },
                },
            ],
            'child_classes': {
                'TextPlugin': ['PicturePlugin', 'LinkPlugin'],
            },
            'parent_classes': {
                'LinkPlugin': ['TextPlugin'],
            },
            'plugin_modules': {
                'LinkPlugin': 'Extra',
            },
            'plugin_labels': {
                'LinkPlugin': 'Add a link',
            },
        },
    },
    'FILE_UPLOAD_TEMP_DIR': mkdtemp(),
    'SITE_ID': 1,
    'THUMBNAIL_PROCESSORS': (
        'easy_thumbnails.processors.colorspace',
        'easy_thumbnails.processors.autocrop',
        'filer.thumbnail_processors.scale_and_crop_with_subject_location',
        'easy_thumbnails.processors.filters',
    ),
    'CMS_TEMPLATES': (
        ('page.html', 'Normal page'),
        ('plugin_with_sekizai.html', 'Plugin with sekizai'),
    ),
    'DJANGOCMS_TRANSLATIONS_CONF': {
        'Bootstrap3ButtonCMSPlugin': {'text_field_child_label': 'label'},
        'DummyLinkPlugin': {'text_field_child_label': 'label'},
    },
    'TEXT_INLINE_EDITING': True,
}

HELPER_SETTINGS['MIGRATION_MODULES'] = DisableMigrations()

if not (__version__ < "4"):  # V4 test?
    HELPER_SETTINGS['INSTALLED_APPS'] += [
        # "djangocms_versioning",  # TODO: Enable tests for versioning
    ]
    HELPER_SETTINGS['CMS_CONFIRM_VERSION4'] = True


def _helper_patch(*args, **kwargs):
    from django.core.management import call_command
    call_command('migrate', run_syncdb=True)


def test():
    from app_helper import runner
    runner.cms('djangocms_text_ckeditor', extra_args=[])


def run():
    from app_helper import runner, utils

    os.environ.setdefault('DATABASE_URL', 'sqlite://localhost/testdb.sqlite')

    # Patch app_helper to create tables
    utils._create_db = _helper_patch

    # we use '.runner()', not '.cms()' nor '.run()' because it does not
    # add 'test' argument implicitly
    runner.runner([sys.argv[0], 'cms', '--cms', 'server', '--bind', '0.0.0.0', '--port', str(port)])


if __name__ == '__main__':
    run()



from django.test import TestCase

from djangocms_text_ckeditor import html, settings


class HtmlSanitizerAdditionalProtocolsTests(TestCase):

    def test_default_tag_escaping(self):
        settings.TEXT_ADDITIONAL_TAGS = []
        parser = html._get_default_parser()
        text = html.clean_html(
            '<iframe src="rtmp://testurl.com/"></iframe>',
            full=False,
            parser=parser,
        )
        self.assertEqual(
            '&lt;iframe src="rtmp://testurl.com/"&gt;&lt;/iframe&gt;',
            text,
        )

    def test_custom_tag_enabled(self):
        settings.TEXT_ADDITIONAL_TAGS = ['iframe']
        parser = html._get_default_parser()
        text = html.clean_html(
            '<iframe src="rtmp://testurl.com/"></iframe>',
            full=False,
            parser=parser,
        )
        self.assertEqual(
            '<iframe src="rtmp://testurl.com/"></iframe>',
            text,
        )

    def test_default_attribute_escaping(self):
        settings.TEXT_ADDITIONAL_ATTRIBUTES = []
        parser = html._get_default_parser()
        text = html.clean_html(
            '<span test-attr="2">foo</span>',
            full=False,
            parser=parser,
        )
        self.assertEqual(
            '<span>foo</span>',
            text,
        )

    def test_custom_attribute_enabled(self):
        settings.TEXT_ADDITIONAL_ATTRIBUTES = ['test-attr']
        parser = html._get_default_parser()
        text = html.clean_html(
            '<span test-attr="2">foo</span>',
            full=False,
            parser=parser,
        )
        self.assertEqual(
            '<span test-attr="2">foo</span>',
            text,
        )

    def test_default_protocol_escaping(self):
        settings.TEXT_ADDITIONAL_PROTOCOLS = []
        parser = html._get_default_parser()
        text = html.clean_html(
            '<source src="rtmp://testurl.com/">',
            full=False,
            parser=parser,
        )
        self.assertEqual('<source>', text)

    def test_custom_protocol_enabled(self):
        settings.TEXT_ADDITIONAL_PROTOCOLS = ['rtmp']
        parser = html._get_default_parser()
        text = html.clean_html(
            '<source src="rtmp://testurl.com/">',
            full=False,
            parser=parser,
        )
        self.assertEqual('<source src="rtmp://testurl.com/">', text)

    def test_clean_html_with_sanitize_enabled(self):
        old_text_html_sanitize = settings.TEXT_HTML_SANITIZE
        settings.TEXT_HTML_SANITIZE = True
        parser = html._get_default_parser()

        original = '<span test-attr="2">foo</span>'
        cleaned = html.clean_html(
            original,
            full=False,
            parser=parser,
        )
        try:
            self.assertHTMLEqual('<span>foo</span>', cleaned)
        finally:
            settings.TEXT_HTML_SANITIZE = old_text_html_sanitize

    def test_clean_html_with_sanitize_disabled(self):
        old_text_html_sanitize = settings.TEXT_HTML_SANITIZE
        settings.TEXT_HTML_SANITIZE = False
        parser = html._get_default_parser()

        original = '<span test-attr="2">foo</span>'
        cleaned = html.clean_html(
            original,
            full=False,
            parser=parser,
        )
        try:
            self.assertHTMLEqual(original, cleaned)
        finally:
            settings.TEXT_HTML_SANITIZE = old_text_html_sanitize



from cms.api import add_plugin

from djangocms_text_ckeditor import html, settings
from djangocms_text_ckeditor.utils import plugin_to_tag

from .base import BaseTestCase
from .fixtures import TestFixture


class WidgetTestCase(TestFixture, BaseTestCase):

    def setUp(self):
        self.super_user = self._create_user('test', True, True)
        self.default_parser = html.DEFAULT_PARSER
        super().setUp()

    def tearDown(self):
        settings.ALLOW_TOKEN_PARSERS = (
            'djangocms_text_ckeditor.attribute_parsers.DataAttributeParser',
        )
        html.DEFAULT_PARSER = self.default_parser

    def test_sub_plugin_config(self):
        page = self.create_page(title='home', template='page.html', language='en')
        plugin = add_plugin(
            self.get_placeholders(page, 'en').get(slot='content'), 'TextPlugin', 'en', body='some text',
        )
        endpoint = self.get_change_plugin_uri(plugin)

        with self.login_user_context(self.user):
            response = self.client.get(endpoint)
            self.assertContains(response, '"group": "Extra"')
            self.assertContains(response, '"title": "Add a link"')
            self.assertContains(response, '"group": "Generic"')
            self.assertContains(response, '"title": "Image"')

    def test_plugin_edit(self):
        page = self.create_page(title='pagina', template='page.html', language='en')
        placeholder = self.get_placeholders(page, 'en').get(slot='content')
        add_plugin(placeholder, 'TextPlugin', 'en', body='Lorem ipsum')
        self.publish(page, 'en')
        response = self.client.get(page.get_absolute_url('en'))
        self.assertContains(response, 'Lorem ipsum')

    def test_child_plugin(self):
        page = self.create_page(title='pagina', template='page.html', language='en')
        placeholder = self.get_placeholders(page, 'en').get(slot='content')
        plugin = add_plugin(placeholder, 'TextPlugin', 'en', body='Lorem ipsum')
        test_image = self.create_filer_image_object()
        pic_plugin = add_plugin(
            placeholder, 'PicturePlugin', 'en', target=plugin, picture=test_image,
        )
        plugin.body = f'{plugin.body} {plugin_to_tag(pic_plugin)}'
        plugin.save()
        self.publish(page, 'en')
        response = self.client.get(page.get_absolute_url('en'))
        self.assertContains(response, 'Lorem ipsum')
        self.assertContains(response, '<img src="/media/')

    def test_contain_text(self):
        page = self.create_page(title='home', template='page.html', language='en')
        placeholder = self.get_placeholders(page, 'en').get(slot='content')
        add_plugin(placeholder, 'TextPlugin', 'en', body='some text')
        language = 'en'
        self.publish(page, 'en')
        url = page.get_absolute_url(language)
        response = self.client.get(url)
        self.assertContains(response, 'some text')

    def test_text_sanitizer(self):
        page = self.create_page(title='home', template='page.html', language='en')
        placeholder = self.get_placeholders(page, 'en').get(slot='content')
        add_plugin(
            placeholder, 'TextPlugin', 'en',
            body='<span data-one="1" data-two="2">some text</span>',
        )
        language = 'en'
        self.publish(page, 'en')
        url = page.get_absolute_url(language)
        response = self.client.get(url)
        self.assertContains(response, 'data-one="1"')
        self.assertContains(response, 'data-two="2"')

    def test_text_sanitizer_no_settings(self):
        settings.ALLOW_TOKEN_PARSERS = []
        html.DEFAULT_PARSER = html._get_default_parser()
        page = self.create_page(title='home', template='page.html', language='en')
        placeholder = self.get_placeholders(page, 'en').get(slot='content')
        add_plugin(
            placeholder, 'TextPlugin', 'en',
            body='<span data-one="1" data-two="2">some text</span>',
        )
        language = 'en'
        self.publish(page, 'en')
        url = page.get_absolute_url(language)
        response = self.client.get(url)
        self.assertContains(response, '<span>some text</span>')



#!/usr/bin/env python
from pathlib import Path

from setuptools import find_packages, setup

from djangocms_text_ckeditor import __version__


REQUIREMENTS = [
    'django-cms>=3.6',
    'html5lib>=1',
    'Pillow',
    'packaging',
]


CLASSIFIERS = [
    'Development Status :: 5 - Production/Stable',
    'Environment :: Web Environment',
    'Intended Audience :: Developers',
    'License :: OSI Approved :: BSD License',
    'Operating System :: OS Independent',
    'Programming Language :: Python',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
    'Programming Language :: Python :: 3.10',
    'Programming Language :: Python :: 3.11',
    'Framework :: Django',
    'Framework :: Django :: 2.2',
    'Framework :: Django :: 3.1',
    'Framework :: Django :: 3.2',
    'Framework :: Django :: 4.0',
    'Framework :: Django :: 4.1',
    'Framework :: Django CMS',
    'Framework :: Django CMS :: 3.6',
    'Framework :: Django CMS :: 3.7',
    'Framework :: Django CMS :: 3.8',
    'Framework :: Django CMS :: 3.9',
    'Framework :: Django CMS :: 3.10',
    'Framework :: Django CMS :: 3.11',
    'Framework :: Django CMS :: 4.0',
    'Framework :: Django CMS :: 4.1',
    'Topic :: Internet :: WWW/HTTP',
    'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    'Topic :: Software Development',
    'Topic :: Software Development :: Libraries',
]

this_directory = Path(__file__).parent
long_description = (this_directory / 'README.rst').read_text()

setup(
    name='djangocms-text-ckeditor',
    version=__version__,
    author='Divio AG',
    author_email='info@divio.ch',
    maintainer='Django CMS Association and contributors',
    maintainer_email='info@django-cms.org',
    url='https://github.com/django-cms/djangocms-text-ckeditor',
    license='BSD-3-Clause',
    description='Text Plugin for django CMS with CKEditor support',
    long_description=long_description,
    long_description_content_type='text/x-rst',
    packages=find_packages(exclude=['tests']),
    include_package_data=True,
    zip_safe=False,
    install_requires=REQUIREMENTS,
    classifiers=CLASSIFIERS,
    python_requires='>=3.7',
    test_suite='tests.settings.test',
)
